@@ -7,6 +7,7 @@ struct gvm_configuration {
 
 	gboolean automount_drives;
 	gboolean automount_media;
+	gboolean autobrowse;
 	gboolean autorun;
 	gchar *autorun_path;
 
@@ -21,6 +22,8 @@ struct gvm_configuration {
 
 	gboolean autophoto;
 	gchar *autophoto_command;
+
+	gchar *eject_command;
 };
 
 /* where our settings are rooted in the gconf tree */
@@ -29,4 +32,6 @@ struct gvm_configuration {
 
 #define CLIPBOARD_NAME		"GVM_SELECTION"
 
+extern gboolean gvm_get_clipboard (void);
+
 #endif	/* _GVM_H */
